# Changelog

## [1.0.1](https://github.com/Mailrify/mailrify-python/compare/v1.0.0...v1.0.1) (2026-02-16)


### Documentation

* Add CI, Release Please, and PyPI publish badges to the README. ([a02f30b](https://github.com/Mailrify/mailrify-python/commit/a02f30b6b5ece8a2c52534794ef1a1ed9304ac8a))

## [1.0.0](https://github.com/Mailrify/mailrify-python/compare/v0.0.4...v1.0.0) (2026-02-16)


### ⚠ BREAKING CHANGES

* complete API redesign, not compatible with 0.1.x

### Features

* initial SDK implementation ([b067d32](https://github.com/Mailrify/mailrify-python/commit/b067d3288a77cfc120683bc8a34adb0c0f8dbe4d))


### Bug Fixes

* support pydantic type evaluation on python 3.9 ([9237800](https://github.com/Mailrify/mailrify-python/commit/9237800485f326acbe03d682f64ccc41883ccb4d))

## Changelog

All notable changes to this project will be documented in this file.
